@@ -8,8 +8,8 @@ from fabric.contrib.console import confirm
 from netaddr import IPNetwork, AddrFormatError
 from ground_soil.fabric import eval_kwargs
 from ground_soil.filesystem import temporary_directory, rsync
-from beanstalk import IDENTIFIER as beanstalk_identifier, BEANSTALK_LOCAL_BASE_PATH
-import beanstalk
+from beanstalk import (IDENTIFIER as beanstalk_identifier, BEANSTALK_LOCAL_BASE_PATH,
+                       __version__ as beanstalk_version_string, VERSION as beanstalk_version_tuple)
 from beanstalk.tasks.utils import (set_verbose_level, load_role_settings as load_beanstalk_settings,
                                    load_web_servers, run_hooked_actions)
 from beanstalk.decorators import beanstalk_role
@@ -249,9 +249,9 @@ def deploy_remote_core():
                 'Please setup beanstalk-stack on this server first.'
             )
         remote_bs_version = json.loads(run('bsjack info.version:USE_JSON=True --hide=status'))
-        if beanstalk.VERSION != tuple(remote_bs_version['list']):
+        if beanstalk_version_tuple != tuple(remote_bs_version['list']):
             abort(red('Hey! Jack at the remote is not the same as me. He\'s {0}. But I\'m {1}.').format(
-                remote_bs_version['string'], beanstalk.__version__))
+                remote_bs_version['string'], beanstalk_version_string))
 
     # Get/Set variables
     beanstalk_settings = env.beanstalk_settings
