@@ -67,6 +67,10 @@ def setup(**settings_patches):
                         install_uwsgi = confirm('Re-install Uwsgi?', default=False)
 
             if install_uwsgi:
+                # Stop services before install it
+                if os.path.exists('/etc/init.d/beanstalk'):
+                    local('/etc/init.d/beanstalk stop')
+
                 with lcd(uwsgi_src_folder):
                     # Create build configuration
                     local('mkdir -p /usr/local/lib/uwsgi')
@@ -77,13 +81,15 @@ def setup(**settings_patches):
                     local('cp uwsgi /usr/local/bin/uwsgi')
                     if not os.path.exists('/usr/bin/uwsgi'):
                         local('ln -s /usr/local/bin/uwsgi /usr/bin/uwsgi')
-                    local('mkdir -p /var/run/beanstalk')
-                    local('cp %s /etc/init.d/beanstalk' % os.path.join(BEANSTALK_ROOT_PATH, 'static/beanstalk_init.sh'))
-                    local('chmod +x /etc/init.d/beanstalk')
                     # mod_uwsgi
                     local('apxs -i -c apache2/mod_uwsgi.c')
                     local('echo "LoadModule uwsgi_module modules/mod_uwsgi.so" > /etc/httpd/conf.d/uwsgi.conf')
 
+    # Init script
+    local('mkdir -p /var/run/beanstalk')
+    local('cp %s /etc/init.d/beanstalk' % os.path.join(BEANSTALK_ROOT_PATH, 'static/beanstalk_init.sh'))
+    local('chmod +x /etc/init.d/beanstalk')
+
     # Do you have user "beanstalk"?
     with settings(hide('everything'), warn_only=True):
         has_beanstalk_user = local('egrep ^beanstalk: /etc/passwd').return_code == 0
