@@ -14,7 +14,6 @@ def add(**settings_patches):
     # Load settings
     load_beanstalk_settings(**settings_patches)
     load_web_servers()
-    ssh_authorized_keys_path = '~/.ssh/authorized_keys'
 
     print tool_title('Beanstalk-Stack users tool')
     print ''
@@ -22,8 +21,6 @@ def add(**settings_patches):
     # Get ssh public key
     ssh_pub_key_path = prompt('Where\'s your ssh public key?', default='~/.ssh/id_rsa.pub',
                               validate=validate_file_existence)
-    with open(ssh_pub_key_path, 'r') as f:
-        ssh_pub_key = f.read().strip()
 
     @roles('web_servers')
     def add_user_core():
